# WorkstreamResponse

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**status** | [**WorkstreamStatusResponse**](WorkstreamStatusResponse.md) |  | 
**status_string** | **str** |  | 
**prefix** | **str** |  | 
**name** | **str** |  | 
**description** | **str** |  | [optional] 
**contact_name** | **str** |  | [optional] 
**contact_number** | **str** |  | [optional] 
**contact_email** | **str** |  | [optional] 
**emergency_contact_name** | **str** |  | [optional] 
**emergency_contact_number** | **str** |  | [optional] 
**organisation_reference** | **str** |  | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

